@@ -61,7 +61,8 @@ def write_default_ansible_cfg(work_dir,
         '/usr/share/ansible/tripleo-plugins/callback:'
         '/usr/share/ansible/plugins/callback:'
         '%s/callback_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
-    callbacks_whitelist = ','.join(['profile_tasks'])
+    callbacks_whitelist = ','.join(['tripleo_dense', 'tripleo_profile_tasks',
+                                    'tripleo_states'])
     action_plugins_path = (
         '~/.ansible/plugins/action:'
         '/usr/share/ansible/plugins/action:'
@@ -91,6 +92,7 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'library', modules_path)
     config.set('defaults', 'callback_plugins', callbacks_path)
     config.set('defaults', 'callback_whitelist', callbacks_whitelist)
+    config.set('defaults', 'stdout_callback', 'tripleo_dense')
     config.set('defaults', 'action_plugins', action_plugins_path)
     config.set('defaults', 'lookup_plugins', lookups_path)
     config.set('defaults', 'filter_plugins', filter_plugins_path)
@@ -345,8 +347,14 @@ class AnsiblePlaybookAction(base.TripleOAction):
         else:
             command = [ansible_playbook_cmd, self.playbook]
 
+        # --limit should always take precedence over blacklisted hosts.
+        # https://bugzilla.redhat.com/show_bug.cgi?id=1857298
         if self.limit_hosts:
             command.extend(['--limit', self.limit_hosts])
+        elif self.blacklisted_hostnames:
+            host_pattern = ':'.join(
+                ['!%s' % h for h in self.blacklisted_hostnames if h])
+            command.extend(['--limit', host_pattern])
 
         if self.module_path:
             command.extend(['--module-path', self.module_path])
@@ -378,11 +386,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if self.inventory:
             command.extend(['--inventory-file', self.inventory])
 
-        if self.blacklisted_hostnames:
-            host_pattern = ':'.join(
-                ['!%s' % h for h in self.blacklisted_hostnames if h])
-            command.extend(['--limit', host_pattern])
-
         if self.tags:
             command.extend(['--tags', self.tags])
 
@@ -419,7 +422,9 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 env_variables.update({
                     # the whitelist could be collected from multiple
                     # arguments if we find a use case for it
-                    'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
+                    'ANSIBLE_CALLBACK_WHITELIST':
+                        'tripleo_dense,tripleo_profile_tasks,tripleo_states',
+                    'ANSIBLE_STDOUT_CALLBACK': 'tripleo_dense',
                     'PROFILE_TASKS_TASK_OUTPUT_LIMIT':
                         six.text_type(self.profile_tasks_limit),
                 })
